# Contributing to `ingest-anything`

Do you want to contribute to this project? Make sure to read this guidelines first :)

## Issue

**When to do it**:

- You found bugs but you don't know how to solve them or don't have time/will to do the solve
- You want new features but you don't know how to implement them or don't have time/will to do the implementation

> ⚠️ _Always check open and closed issues before you submit yours to avoid duplicates_

**How to do it**:

- Open an issue
- Give the issue a meaningful title (short but effective problem description)
- Describe the problem

## Traditional contribution

**When to do it**:

- You found bugs and corrected them
- You optimized/improved the code
- You added new features that you think could be useful to others

**How to do it**:

1. Fork this repository
2. Test your changes locally

```
uv pip install hatch
cd PdfItDown/
hatch run test
```

3. If all the test pass, you can commit your changes.
4. Submit pull request (make sure to provide a thorough description of the changes)

> [!NOTE] > _If you add a new feature, you might need to add new tests!_

### Thanks for contributing!
